"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const extendWithFirebaseConfig_1 = tslib_1.__importDefault(require("./extendWithFirebaseConfig"));
const tasks = tslib_1.__importStar(require("./tasks"));
/**
 * Cypress plugin which attaches tasks used by custom commands
 * and returns modified Cypress config. Modified config includes
 * env setting with values of Firebase specific environment variables
 * such as GCLOUD_PROJECT, FIREBASE_DATABASE_EMULATOR_HOST,
 * FIRESTORE_EMULATOR_HOST and FIREBASE_AUTH_EMULATOR_HOST.
 * @param cypressOnFunc - on function from cypress plugins file
 * @param cypressConfig - Cypress config
 * @returns Extended Cypress config
 */
function pluginWithTasks(cypressOnFunc, cypressConfig) {
    // Attach tasks to Cypress using on function
    // NOTE: any is used because cypress doesn't export Task or Tasks types
    cypressOnFunc('task', tasks);
    // Return extended config
    return (0, extendWithFirebaseConfig_1.default)(cypressConfig);
}
exports.default = pluginWithTasks;
