import { UserRecord } from 'firebase-admin/auth';
import { FixtureData, FirestoreAction, RTDBAction, CallRtdbOptions, CallFirestoreOptions } from './attachCustomCommands';
import { AppOptions } from './types';
/**
 * @param action - Action to run
 * @param actionPath - Path in RTDB
 * @param options - Query options
 * @param data - Data to pass to action
 * @returns Promise which resolves with results of calling RTDB
 */
export declare function callRtdb(action: RTDBAction, actionPath: string, options?: CallRtdbOptions, data?: FixtureData | string | boolean): Promise<any>;
/**
 * @param action - Action to run
 * @param actionPath - Path to collection or document within Firestore
 * @param options - Query options
 * @param data - Data to pass to action
 * @returns Promise which resolves with results of calling Firestore
 */
export declare function callFirestore(action: FirestoreAction, actionPath: string, options?: CallFirestoreOptions, data?: FixtureData): Promise<any>;
export interface CustomTokenTaskSettings extends AppOptions {
    uid: string;
    customClaims?: Record<string, unknown>;
}
/**
 * Create a custom token
 * @param settings - Settings object
 * @returns Promise which resolves with a custom Firebase Auth token
 */
export declare function createCustomToken(settings: CustomTokenTaskSettings): Promise<string>;
export interface GetAuthUserTaskSettings extends AppOptions {
    uid: string;
}
/**
 * Get Firebase Auth user based on UID
 * @param settings - Task settings
 * @param settings.uid - UID of user for which the custom token will be generated
 * @param settings.tenantId - Optional ID of tenant used for multi-tenancy
 * @returns Promise which resolves with a custom Firebase Auth token
 */
export declare function getAuthUser(settings: GetAuthUserTaskSettings): Promise<UserRecord>;
